@@ -16,21 +16,17 @@ test_that("fable dplyr verbs", {
   
   fbl_complex %>%
     filter(key == "mdeaths") %>%
-    select(index, .model, value, .distribution) %>% 
+    select(index, .model, value, .mean) %>% 
     n_keys() %>% 
     expect_equal(2)
   
   expect_equal(
     colnames(hilo(fbl_complex, level = c(50, 80, 95))),
-    if(packageVersion("tsibble") >= "0.8.9.9000"){
-      c("index", "key", ".model", "value", "50%", "80%", "95%")
-    } else {
-      c("key", ".model", "index", "value", "50%", "80%", "95%")
-    }
+    c("key", ".model", "index", "value", ".mean", "50%", "80%", "95%")
   )
   
   expect_equivalent(
     as.list(fbl_multi),
-    as.list(rbind(fbl_multi[1:12,], fbl_multi[13:24,]))
+    as.list(bind_rows(fbl_multi[1:12,], fbl_multi[13:24,]))
   )
 })
